# badewanne.py

from grafikfenster import *
from math import pi,radians
from moebel import Moebel

### ---------------------------------------------------
class Badewanne(Moebel):
    """Klasse Badewanne
    ermoeglicht das Zeichnen und Bearbeiten eines
    Badewanne-Symbols fuer den Raumplaner"""

    def __init__(self,
                 xPos=10,
                 yPos=10,
                 breite=200,
                 tiefe=80,
                 winkel=0,
                 farbe='magenta',
                 fuellfarbe=None,
                 sichtbar=False):
        """Konstruktor mit vordefinierten Parametern
        Konstruktor der Oberklasse aufrufen!"""
        Moebel.__init__(self, xPos, yPos, breite, tiefe, winkel, farbe, fuellfarbe, sichtbar)
        if sichtbar: self.Zeige()
        
    def GibFigur(self):
        """definiert die zu zeichnende Figur"""
        path = self.GibZeichenPfad()
        
        # lokale Variable zur Schreibvereinfachung
        b, t = self.GibBreite(), self.GibTiefe()
        # Die Badewanne kann auch sinnvoll in der Originalversion
        # ohne Teilpfade eingesetzt werden

        path1 = self.GibZeichenPfad()
        path1.AddRectangle(0, 0, b, t)
        path1.MoveToPoint(b - 0.5*t, 0.9*t)
        path1.AddLineToPoint(0.1*t, 0.9*t)
        path1.AddLineToPoint(0.1*t, 0.1*t)
        path1.AddLineToPoint(b - 0.5*t, 0.1*t)
        path1.MoveToPoint(b - 0.5*t, 0.9*t)
        path1.AddArc(b - 0.5*t, 0.5*t, 0.4*t, pi*90/180, pi*270/180, False)
        path1.AddEllipse(0.1*b, 0.5*t-3, 6, 6) # weglassen fuer ohne Fuellung
        path.AddPath(path1)
        ##
        path2 = self.GibZeichenPfad()
        path2.MoveToPoint(b - 0.5*t, 0.9*t)
        path2.AddLineToPoint(0.1*t, 0.9*t)
        path2.AddLineToPoint(0.1*t, 0.1*t)
        path2.AddLineToPoint(b - 0.5*t, 0.1*t)
        path2.MoveToPoint(b - 0.5*t, 0.9*t)
        path2.AddArc(b - 0.5*t, 0.5*t, 0.4*t, pi*90/180, pi*270/180, False)
        path.AddPath(path2)
        ##
        path3 = self.GibZeichenPfad()
        path3.AddEllipse(0.1*b, 0.5*t-3, 6, 6)
        path.AddPath(path3)

        return self.Transformiere(path)


### ---------------------------------------------------
class BadewanneApp(wx.App):
    """Test-Anwendung speziell fuer Tisch"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        #self.fenster.ZeigeFillingFrame()
        self.TestAnwendung()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global badewanne
        badewanne=Badewanne(200, 200, winkel=90, farbe="magenta",fuellfarbe='LIGHT GRAY', sichtbar=True)
        
### ---------------------------------------------------
if __name__ == '__main__':
    app = BadewanneApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
